==> php-embed_4.4.4.orig.tar.xz: php-embed-4.4.4/tests/fixtures/www.youtube.com.playlist.13d1655ccf6cbdc1fc0162c6a02f822a.php <==
<?php
declare(strict_types = 1);

return [
    'authorName' => 'Scadrei5',
    'authorUrl' => 'https://consent.youtube.com/user/Scadrei5',
    'cms' => null,
    'code' => [
        'html' => '<iframe width="200" height="113" src="https://www.youtube.com/embed/videoseries?list=PL4qTakKkQATKOyZPJG_cAMnRtF7fAIdST" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>',
        'width' => 200,
        'height' => 113,
        'ratio' => 56.5
    ],
    'description' => null,
    'favicon' => 'https://www.google.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://i.ytimg.com/vi/CdbnVwot6lc/hqdefault.jpg',
    'keywords' => [],
    'language' => 'es',
    'languages' => [],
    'license' => null,
    'providerName' => 'YouTube',
    'providerUrl' => 'https://www.youtube.com/',
    'publishedTime' => null,
    'redirect' => 'https://consent.youtube.com/\'https:/consent.youtube.com/ml?continue=https://www.youtube.com/playlist?list%3DPL4qTakKkQATKOyZPJG_cAMnRtF7fAIdST&gl=ES&hl=es&pc=yt&uxe=23983172&src=1&rffu=true\'',
    'title' => 'De espaldas al patriarcado',
    'url' => 'https://www.youtube.com/playlist?list=PL4qTakKkQATKOyZPJG_cAMnRtF7fAIdST',
    'linkedData' => [],
    'oEmbed' => [
        'title' => 'De espaldas al patriarcado',
        'author_name' => 'Scadrei5',
        'author_url' => '/user/Scadrei5',
        'type' => 'video',
        'height' => 113,
        'width' => 200,
        'version' => '1.0',
        'provider_name' => 'YouTube',
        'provider_url' => 'https://www.youtube.com/',
        'thumbnail_height' => 360,
        'thumbnail_width' => 480,
        'thumbnail_url' => 'https://i.ytimg.com/vi/CdbnVwot6lc/hqdefault.jpg',
        'html' => '<iframe width="200" height="113" src="https://www.youtube.com/embed/videoseries?list=PL4qTakKkQATKOyZPJG_cAMnRtF7fAIdST" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>',
        'url' => 'https://www.youtube.com/playlist?list=PL4qTakKkQATKOyZPJG_cAMnRtF7fAIdST'
    ]
];

==> php-embed_4.4.7.orig.tar.xz: php-embed-4.4.7/tests/fixtures/www.youtube.com.playlist.13d1655ccf6cbdc1fc0162c6a02f822a.php <==
<?php
declare(strict_types = 1);

return [
    'authorName' => 'Scadrei5',
    'authorUrl' => 'https://consent.youtube.com/user/Scadrei5',
    'cms' => null,
    'code' => [
        'html' => '<iframe width="200" height="113" src="https://www.youtube.com/embed/videoseries?list=PL4qTakKkQATKOyZPJG_cAMnRtF7fAIdST" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>',
        'width' => 200,
        'height' => 113,
        'ratio' => 56.5
    ],
    'description' => null,
    'favicon' => 'https://www.google.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://i.ytimg.com/vi/CdbnVwot6lc/hqdefault.jpg',
    'keywords' => [],
    'language' => 'es',
    'languages' => [],
    'license' => null,
    'providerName' => 'YouTube',
    'providerUrl' => 'https://www.youtube.com/',
    'publishedTime' => null,
    'redirect' => 'https://consent.youtube.com/ml?continue=https://www.youtube.com/playlist?list%3DPL4qTakKkQATKOyZPJG_cAMnRtF7fAIdST&gl=ES&hl=es&pc=yt&uxe=23983172&src=1&rffu=true',
    'title' => 'De espaldas al patriarcado',
    'url' => 'https://www.youtube.com/playlist?list=PL4qTakKkQATKOyZPJG_cAMnRtF7fAIdST',
    'linkedData' => [],
    'oEmbed' => [
        'title' => 'De espaldas al patriarcado',
        'author_name' => 'Scadrei5',
        'author_url' => '/user/Scadrei5',
        'type' => 'video',
        'height' => 113,
        'width' => 200,
        'version' => '1.0',
        'provider_name' => 'YouTube',
        'provider_url' => 'https://www.youtube.com/',
        'thumbnail_height' => 360,
        'thumbnail_width' => 480,
        'thumbnail_url' => 'https://i.ytimg.com/vi/CdbnVwot6lc/hqdefault.jpg',
        'html' => '<iframe width="200" height="113" src="https://www.youtube.com/embed/videoseries?list=PL4qTakKkQATKOyZPJG_cAMnRtF7fAIdST" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>',
        'url' => 'https://www.youtube.com/playlist?list=PL4qTakKkQATKOyZPJG_cAMnRtF7fAIdST'
    ]
];
